==> qtjambi-remoteobjects-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiRemoteObjects/QRemoteObjectHostBase_shell.h <==
#ifndef QREMOTEOBJECTHOSTBASE_SHELL_H
#define QREMOTEOBJECTHOSTBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectHostBase_shell : public QRemoteObjectHostBase, public QtJambiShellInterface
{
public:
    ~QRemoteObjectHostBase_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QUrl hostUrl() const override;
    bool setHostUrl(const QUrl& hostAddress0, QRemoteObjectHostBase::AllowedSchemas allowedSchemas1) override;
    void setName(const QString& name0) override;
    bool setRegistryUrl(const QUrl& registryAddress0) override;
    void timerEvent(QTimerEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectHostBase_access : public QRemoteObjectHostBase
{
    jobject __qt_hostUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_setHostUrl_cref_QUrl_QRemoteObjectHostBase_AllowedSchemas(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID hostAddress0, jint allowedSchemas1);
    void __qt_setName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
};

#endif // QREMOTEOBJECTHOSTBASE_SHELL_H

==> qtjambi-remoteobjects-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiRemoteObjects/QRemoteObjectHostBase_shell.h <==
#ifndef QREMOTEOBJECTHOSTBASE_SHELL_H
#define QREMOTEOBJECTHOSTBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectHostBase_shell : public QRemoteObjectHostBase, public QtJambiShellInterface
{
public:
    ~QRemoteObjectHostBase_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QUrl hostUrl() const override;
    bool setHostUrl(const QUrl& hostAddress0, QRemoteObjectHostBase::AllowedSchemas allowedSchemas1) override;
    void setName(const QString& name0) override;
    bool setRegistryUrl(const QUrl& registryAddress0) override;
    void timerEvent(QTimerEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectHostBase_access : public QRemoteObjectHostBase
{
    jobject __qt_hostUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_setHostUrl_cref_QUrl_QRemoteObjectHostBase_AllowedSchemas(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID hostAddress0, jint allowedSchemas1);
    void __qt_setName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
};

#endif // QREMOTEOBJECTHOSTBASE_SHELL_H
